@@ -1,8 +1,10 @@
-use crate::{clock::Epoch, program_error::ProgramError, pubkey::Pubkey};
-use std::{
-    cell::{Ref, RefCell, RefMut},
-    cmp, fmt,
-    rc::Rc,
+use {
+    crate::{clock::Epoch, program_error::ProgramError, pubkey::Pubkey},
+    std::{
+        cell::{Ref, RefCell, RefMut},
+        cmp, fmt,
+        rc::Rc,
+    },
 };
 
 /// Account information
